@@ -27,7 +27,8 @@ class PrestaShopWebservice(object):
     you can generate one from your Back Office and click on the
     "Tools / Web Service" tab.
 
-    `Read More <http://doc.prestashop.com/display/PS14/Chapter+1+-+Creating+Access+to+Back+Office>`_
+    `Read More <http://doc.prestashop.com/display/PS14/\
+            Chapter+1+-+Creating+Access+to+Back+Office>`_
     """
 
     def __init__(self, url, key, debug=False):
@@ -128,7 +129,8 @@ class ResourceProxy(object):
         return objectify.fromstring(response.content)
 
     @staticmethod
-    def make_params(display=None, filters=None, sort=None, limit=None, offset=None):
+    def make_params(display=None, filters=None,
+                    sort=None, limit=None, offset=None, date=None):
         """
         Builds the URL paramters as a dictionary
 
@@ -140,11 +142,16 @@ class ResourceProxy(object):
                      eg: [('firstname', 'ASC'), ('lastname', 'DESC')]
         :param limit: The number of records to be returned
         :param offset: The number of records to skip
+        :param date: This should be a logically True value to have a date based
+                     filter. For details,
+                     `refer <http://www.prestashop.com/forums/topic/\
+                             101502-webservice-api-filter-for-date-ranges/>`_
         """
         params = {}
 
         if display:
-            params['display'] = '[' + ','.join(display) + ']'
+            params['display'] = display if display == 'full' \
+                else '[' + ','.join(display) + ']'
 
         if filters:
             for key, value in filters.iteritems():
@@ -160,11 +167,14 @@ class ResourceProxy(object):
         elif limit and offset:
             params['limit'] = '%d,%d' % (offset - 1, limit)
 
+        if date:
+            params['date'] = 1
+
         return params
 
     @classmethod
     def get_list(cls, as_ids=False, display=None,
-                 filters=None, sort=None, limit=None, offset=None):
+                 filters=None, sort=None, limit=None, offset=None, date=None):
         """
         Gets a list of records by sending GET on the Collection
         URI of the resource.
@@ -173,20 +183,26 @@ class ResourceProxy(object):
                        XML object is returned
         :param display: A list of fields that needs to be returned.
                         By default only the ID is fetched
+        :param filters: A dictionary of field name and values
+                        eg: {'firstname': 'sharoon'}
+        :param sort: a list of tuple of field and value
+                     eg: [('firstname', 'ASC'), ('lastname', 'DESC')]
+        :param limit: The number of records to be returned
+        :param offset: The number of records to skip
+        :param date: This should be a logically True value to have a date based
+                     filter.
         """
         if display is None:
             display = []
 
-        if as_ids and 'id' not in display:
+        if as_ids and 'id' not in display and display != 'full':
             display.append('id')
 
-        params = cls.make_params(display, filters, sort, limit, offset)
-
+        params = cls.make_params(display, filters, sort, limit, offset, date)
         response = cls.session.get(cls.url, params=params)
         cls.check_status(response)
         rv = objectify.fromstring(response.content)
 
-
         if as_ids:
             return map(
                 lambda r: int(r.id),
